@@ -12,8 +12,14 @@
 
 #define LLDB_CONFIG_TERMIOS_SUPPORTED
 
+#define LLDB_EDITLINE_USE_WCHAR 0
+
+#define LLDB_HAVE_EL_RFUNC_T 1
+
 /* #undef LLDB_DISABLE_POSIX */
 
+#define LLDB_LIBDIR_SUFFIX ""
+
 #define HAVE_SYS_EVENT_H 0
 
 #define HAVE_PPOLL 1
@@ -24,6 +30,8 @@
 
 #define HAVE_NR_PROCESS_VM_READV 1
 
+#ifndef HAVE_LIBCOMPRESSION
 /* #undef HAVE_LIBCOMPRESSION */
+#endif
 
 #endif // #ifndef LLDB_HOST_CONFIG_H
